@@ -1,5 +1,7 @@
 pub mod completions;
-pub mod config;
+// pub mod config;
+pub mod configure;
 pub mod connect;
 pub mod default;
 pub mod list;
+pub mod profile;
