@@ -1,10 +1,7 @@
-use crate::utils::config::CONFIG;
 use anyhow::Result;
-use std::process::Child;
-use std::process::Command;
-use std::process::ExitStatus;
+use std::process::{Child, Command, ExitStatus};
 
-use crate::utils;
+use crate::utils::spinner;
 
 pub fn is_logged_in() -> Result<bool> {
     let output = Command::new("tsh").args(["status"]).output()?;
@@ -13,16 +10,16 @@ pub fn is_logged_in() -> Result<bool> {
     Ok(is_logged_in)
 }
 
-pub fn login(proxy: &str, auth: Option<&String>) -> Result<ExitStatus> {
+pub fn login(proxy: &str, auth: Option<&String>, user: &str) -> Result<ExitStatus> {
     let proxy_args = format!("--proxy={}", proxy);
     let mut args = vec!["login", proxy_args.as_str()];
 
+    let user_args = format!("--user={}", user);
+    args.push(user_args.as_str());
+
     let auth_args;
-    if let Some(auth) = auth {
-        auth_args = format!("--auth={}", auth);
-        args.push(auth_args.as_str());
-    } else if CONFIG.auth.is_some() {
-        auth_args = format!("--auth={}", CONFIG.auth.as_ref().unwrap());
+    if auth.is_some() {
+        auth_args = format!("--auth={}", auth.unwrap());
         args.push(auth_args.as_str());
     }
 
@@ -36,10 +33,24 @@ pub fn ls(format: Option<&String>) -> Result<String> {
         Some(format) => format,
         None => "text",
     };
-    let spinner = utils::spinner::get_spinner();
+    let spinner = spinner::get_spinner();
     spinner.set_message("Getting nodes from teleport...");
     let output = Command::new("tsh").args(["ls", "-f", format]).output()?;
 
     spinner.finish_and_clear();
     Ok(String::from_utf8_lossy(&output.stdout).to_string())
 }
+
+pub fn cmp_logged_in_proxy_with(proxy: &str) -> Result<bool> {
+    let output = Command::new("tsh").args(["status"]).output()?;
+    let stdout = String::from_utf8_lossy(&output.stdout);
+    let logged_in_proxy = stdout
+        .lines()
+        .next()
+        .unwrap()
+        .split_ascii_whitespace()
+        .nth(3)
+        .unwrap();
+    let proxy = format!("https://{}:443", proxy.split(':').next().unwrap());
+    Ok(proxy == logged_in_proxy)
+}
